@@ -39,14 +39,12 @@ import os
 import sys
 import time
 import traceback
-import pkg_resources
 from copy import deepcopy
 from datetime import datetime
 
 import numpy as np
 from numpy.linalg import multi_dot
 
-import geometric
 from .info import print_logo, print_citation
 from .internal import CartesianCoordinates, PrimitiveInternalCoordinates, DelocalizedInternalCoordinates
 from .ic_tools import check_internal_grad, check_internal_hess, write_displacements
@@ -56,6 +54,7 @@ from .prepare import get_molecule_engine, parse_constraints
 from .params import OptParams, parse_optimizer_args
 from .nifty import row, col, flat, bohr2ang, ang2bohr, logger, bak, createWorkQueue, destroyWorkQueue
 from .errors import InputError, HessianExit, EngineError, GeomOptNotConvergedError, GeomOptStructureError, LinearTorsionError
+from .config import config_dir
 
 class Optimizer(object):
     def __init__(self, coords, molecule, IC, engine, dirname, params, print_info=True):
@@ -790,8 +789,7 @@ def run_optimizer(**kwargs):
     # This behavior may be changed by editing the log.ini file.
     # Output will only be written to log files after the 'logConfig' line is called!
     if kwargs.get('logIni') is None:
-        import geometric.optimize
-        logIni = pkg_resources.resource_filename(geometric.optimize.__name__, 'config/log.ini')
+        logIni = os.path.join(config_dir, 'log.ini')
     else:
         logIni = kwargs.get('logIni')
     logfilename = kwargs.get('prefix')
